<?php
/*
 *	Author	 :		Lucas Baltes
 *				$Author: lhb $
 *
 *  				Version 2.0 by Miguel Angelo Rozsas 
 *				(miguel@rozsas.xx.nom.br
 *
 *	Copyright:		Lucas Baltes <lucas at thebobo dot com>
 *
 *	Date	 :		$Date: $
 *	Rev      :		$Revision: $
 *
 *	Purpose	 :		This file defines the configuration 
 *				settings for aNTG. The only
 *				setting you probably want to change is $if_array.
 */

# system defaults
define("SMARTY_DIR", dirname(__FILE__) . "/includes/");
require_once(SMARTY_DIR . 'Smarty.class.php');

define("VERSION", "2.2");

# initialize smarty
$smarty = new smarty;
$smarty->debugging = false;

# 
# user preferences
#
define ("DEFAULT_IF", "eth0");
define ("DEFAULT_VIEW", "month");

#
# constants
#
define("TABLE", "antg2");
define ("VGRAPH_H", "200"); # height of vertical graph in pixels.
						 
#
# auxiliary values
#
define("CURRENT_YEAR", date('Y'));
define("CURRENT_MONTH", date('n'));
define("CURRENT_DAY", date('j'));
$smarty->assign ("zero", 0); 

#
# create several arrays to be used in selects
# 

# FIXME: This static list of interfaces isn't good.
# FIXME: Interfaces can be added or removed from the system over time.
# FIXME: Of course I can SELECT if_name from the table,
# FIXME: but this is too time expensive. Any alternatives ?


# if_array and the derivated ifs_list and str_ifs_list are used to built the interface select form
$if_array= array (
	"%" => "*", 
	"lo" => "loopback",
	"eth0" => "eth0",
	"eth1" => "eth1",
	"tst0" => "tst0");

#
# End of user configurable options
# From this point, the user may have nothing to change.
#

# if_array and the derivated ifs_list and str_ifs_list are used to built the interface select form
$if_keys= array_keys ($if_array);
$if_values= array_values ($if_array);
$smarty->assign ("ifs_list", $if_keys);
$smarty->assign ("str_ifs_list", $if_values);

# days_list is used to built the day select form
$smarty->assign ("days_list", range (1, 31));

# num_months_list is used to built the months select form
$smarty->assign ("num_months_list", range (0, 12));

# str_months_list is used to built values for the months select form
$tmp[]= "current";
for ($i= 1; $i<=12; $i++) {
  $tmp[]= date('M', mktime(0, 0, 0, $i, 1, 2000));
}
$smarty->assign ("str_months_list", $tmp);

# years_list is used to built the year select form
$years_list[] = "current";
for ($i=(CURRENT_YEAR-5); $i <= CURRENT_YEAR; $i++) {
	$years_list[] = $i;
}
$smarty->assign("years_list", $years_list);

#
# Functions
#

# return the number of days in a month
function get_days_in_month($year,$month)
{
	$date=getdate(mktime(0,0,0,$month+1,0,$year));
	return $date["mday"];
}

# return the proper short index string
function short_idx($idx, $view)
{
	switch ($view)
	{
		case "day":
			$short= date('H', mktime($idx, 0, 0, 1, 1, 1));
			break;
			
		case "month":
			$week= date('D', mktime(0, 0, 0, $GLOBALS['sel_month'], $idx, $GLOBALS['sel_year']));
			$short= date('d', mktime(0, 0, 0, $GLOBALS['sel_month'], $idx, $sel_year));
			if (($week=="Sun") || ($week=="Sat")) {
				$short= "<b>" . $short . "<b>";
			}
			break;
			
		case "year":
			$short= date('M', mktime(0, 0, 0, $idx, 1, 2000));
			break;
			
		default:
			$short= "?";
			break;
	}	
	return ($short);
}

# return the proper short index string
function long_idx($idx, $view)
{
	switch ($view)
	{
		case "day":
			$long= $idx . ":00h - " . $idx . ":59h";
			break;
			
		case "month":
			$week= date('D', mktime(0, 0, 0, $GLOBALS['sel_month'], $idx, $GLOBALS['sel_year']));
			$short= date('d', mktime(0, 0, 0, $GLOBALS['sel_month'], $idx, $GLOBALS['sel_year']));
			if (($week=="Sun") || ($week=="Sat")) {
				$long= "<b>$week&nbsp;&nbsp;$short</b>";
			} else {
				$long= "$week&nbsp;&nbsp;$short";
			}
			break;
			
		case "year":
			$long= date('F', mktime(0, 0, 0, $idx, 1, 2000));
			break;
			
		default:
			$long= "?";
			break;
	}	
	return ($long);
}

// What is better reference value? max, min, mean or even (max_tx+max_rx) 
// as reference value for compute a scale multiplier ?
// I use the following rule: as more detailed is the view, more detail I want t
// o see. As more general is the view, less details I want to see. You can take ano
// ther approach, of course. Just pick up the best reference value you want in each
// view.

function best_scale ($view)
{
    switch ($view)
    {
        case "day":
            $ref= min($GLOBALS['min_tx'], $GLOBALS['min_rx']);
            break;
        case "month":
            $ref= max($GLOBALS['min_tx'], $GLOBALS['min_rx']);
            break;
        case "year":
            $ref= $GLOBALS['max_io']-max($GLOBALS['max_tx'], $GLOBALS['max_rx']);
            break;
        default:
            $ref= max($GLOBALS['min_tx'], $GLOBALS['min_rx']);
    }
    $k= (integer)(log($ref)/log(2));
    $k= ((integer)($k / 10)) * 10;
    return ($k);
}
?>
